# -*- coding: utf-8 -*-
"""
Sistema de Consulta Pública

Copyleft (@) 2017 CENDITEL nodo Mérida - https://planificacion.cenditel.gob.ve/trac/wiki/ModeladoTopicos_2017
"""
## @package base.functions
#
# Clases genéricas de la consulta
# @author Rodrigo Boet (rboet at cenditel.gob.ve)
# @author <a href='http://www.cenditel.gob.ve'>Centro Nacional de Desarrollo e Investigación en Tecnologías Libres
# (CENDITEL) nodo Mérida - Venezuela</a>
# @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
# @version 1.0
from __future__ import unicode_literals
from consulta.models import Consulta,TipoPregunta
import requests
import copy

def cargar_tipo_pregunta():
    """!
    Función que permite cargar los tipos de preguntas que existen

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 15-02-2017
    @return Devuelve una tupla con los tipos de pregunta
    """

    lista = ('', 'Seleccione...'),

    try:
        for tipo_pregunta in TipoPregunta.objects.all():
            lista += (tipo_pregunta.id, tipo_pregunta.tipo),
    except Exception as e:
        pass

    return lista

def cargar_consulta():
    """!
    Función que permite cargar las consultas

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 22-02-2017
    @return Devuelve una tupla con las consultas
    """

    lista = ('', 'Seleccione...'),

    try:
        for consulta in Consulta.objects.all():
            lista += (consulta.id, consulta.nombre_consulta),
    except Exception as e:
        pass

    return lista


def cargar_ministerios():
    """!
    Función que permite cargar los ministerios

    @author Antonio Araujo (aaraujo at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 15-03-2017
    @return Devuelve una tupla con los ministerios
    """

    # TODO: especificar la URL del servicio a traves de una configuracion y gestion
    # de error en solicitud http
    url =  'http://192.168.12.152:8080/services_sipes/entes_planificadores/views/servicios_webs?display_id=page_1'
    r = requests.get(url)

    if not r.status_code == 200:
        print "ERROR:"
        return ('', 'ocurrio error...'),

    data = r.json()
    # tupla de entes
    tuplaNameEntity = ('', 'Ministerios '),
    uniqueEntities = []
    nidEntities = []

    for dicc in data:
        tmpEntity = dicc['name_ente']
        tmpNidEntity = dicc['nid']
        if  tmpEntity.startswith('Ministerio') and  tmpEntity not in uniqueEntities:
            uniqueEntities.append(tmpEntity)
            nidEntities.append(tmpNidEntity)
        else:
            continue

    for i in range(0, len(uniqueEntities)) :
        tuplaNameEntity += (nidEntities[i], uniqueEntities[i]),

    return tuplaNameEntity


def cargar_vicepresidencias():
    """!
    Función que permite cargar las vicepresidencias

    @author Antonio Araujo (aaraujo at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 15-03-2017
    @return Devuelve una tupla con las vicepresidencias
    """

    # TODO: especificar la URL del servicio a traves de una configuracion y gestion
    # de error en solicitud http
    url =  'http://192.168.12.152:8080/services_sipes/entes_planificadores/views/servicios_webs?display_id=page_1'
    r = requests.get(url)
    if not r.status_code == 200:
        print "ERROR:"
        return ('', 'ocurrio error...'),

    data = r.json()

    # tupla de sectores
    tuplaSector = ('', 'Vicepresidencias'),
    uniqueSectors = []
    nidEntities = []

    for dicc in data:
        tmpSector = dicc['sector']
        tmpNidEntity = dicc['nid']
        if tmpSector.startswith('Vicepresidencia') and tmpSector not in uniqueSectors:
            uniqueSectors.append(tmpSector)
            nidEntities.append(tmpNidEntity)
        else:
            continue

    for i in range(0, len(uniqueSectors)) :
        tuplaSector += (nidEntities[i], uniqueSectors[i]),

    return tuplaSector


def cargar_ambitos():
    """!
    Función que permite cargar los ambitos

    @author Antonio Araujo (aaraujo at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 22-03-2017
    @return Devuelve una tupla con los ambitos
    """

    # TODO: especificar la URL del servicio a traves de una configuracion y gestion
    # de error en solicitud http
    url = 'http://192.168.12.152:8080/services_sipes/entes_planificadores/views/lista_ambitos_y_sectores?display_id=ambitos'
    r = requests.get(url)
    if not r.status_code == 200:
        print "ERROR:"
        return ('', 'ocurrio error...'),

    data = r.json()

    tuplaScope = ('', 'Seleccione...'),

    for dicc in data:
        if dicc['parent_id'] == '0' :
            tuplaScope += (dicc['id'], dicc['nombre']),

    return tuplaScope

def cargar_sectores():
    """!
    Función que permite cargar los sectores

    @author Antonio Araujo (aaraujo at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 22-03-2017
    @return Devuelve una tupla con los ambitos
    """

    # TODO: especificar la URL del servicio a traves de una configuracion y gestion
    # de error en solicitud http
    url = 'http://192.168.12.152:8080/services_sipes/entes_planificadores/views/lista_ambitos_y_sectores?display_id=ambitos'
    r = requests.get(url)
    if not r.status_code == 200:
        print "ERROR:"
        return ('', 'ocurrio error...'),

    data = r.json()
    tuplaSector = ('', 'Seleccione...'),

    for dicc in data:
        if dicc['parent_id'] != '0' :
            tuplaSector += (dicc['parent_id'], dicc['nombre']),

    return tuplaSector