# -*- coding: utf-8 -*-
"""
Sistema de Consulta Pública

Copyleft (@) 2017 CENDITEL nodo Mérida - https://planificacion.cenditel.gob.ve/trac/wiki/ModeladoTopicos_2017
"""
## @package participacion.forms
#
# Formulario correspondiente a la aplicación participación
# @author Rodrigo Boet (rboet at cenditel.gob.ve)
# @author <a href='http://www.cenditel.gob.ve'>Centro Nacional de Desarrollo e Investigación en Tecnologías Libres
# (CENDITEL) nodo Mérida - Venezuela</a>
# @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
# @version 1.0
from django import forms
from base.functions import cargar_consulta, cargar_ministerios, cargar_vicepresidencias, cargar_ambitos, cargar_sectores


class ParticipacionSelectForm(forms.Form):
    """!
    Clase del formulario que muestra las consultas

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 22-02-2017
    @version 1.0.0
    """

    def __init__(self, *args, **kwargs):
        """!
        Metodo que sobreescribe cuando se inicializa el formulario

        @author Rodrigo Boet (rboet at cenditel.gob.ve)
        @copyright GNU/GPLv2
        @date 22-02-2017
        @param self <b>{object}</b> Objeto que instancia la clase
        @param args <b>{list}</b> Lista de los argumentos
        @param kwargs <b>{dict}</b> Diccionario con argumentos
        @return Retorna el formulario validado
        """
        super(ParticipacionSelectForm, self).__init__(*args, **kwargs)

        self.fields['consultas'].choices = cargar_consulta()

    ## Consulta
    consultas = forms.ChoiceField(widget=forms.Select(attrs={'class':'form-control'}),
        label="Selecione una consulta")


class ParticipacionSearchForm(forms.Form):
    """!
    Clase del formulario de búsqueda

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 23-02-2017
    @version 1.0.0
    """

    def __init__(self, *args, **kwargs):
        super(ParticipacionSearchForm, self).__init__(*args, **kwargs)
        self.fields['entes'].choices = (('','Seleccione..'),)+cargar_vicepresidencias()+cargar_ministerios()
        self.fields['ambito'].choices = cargar_ambitos()
        self.fields['sector'].choices = cargar_sectores()

    ## Entes
    entes = forms.ChoiceField(widget=forms.Select(attrs={'class':'form-control'}),
        label="Selecione un ente", required=False)

    ## Estado
    estado = forms.ChoiceField(widget=forms.Select(attrs={'class':'form-control'}),
        label="Selecione un estado", required=False)

    ## Municipio
    municipio = forms.ChoiceField(widget=forms.Select(attrs={'class':'form-control'}),
        label="Selecione un municipio", required=False)

    ## Parroquia
    parroquia = forms.ChoiceField(widget=forms.Select(attrs={'class':'form-control'}),
        label="Selecione una parroaquia", required=False)

    ## Ámbito
    ambito = forms.ChoiceField(widget=forms.Select(attrs={'class':'form-control'}),
        label="Selecione un ambito",required=False)

    ## Sector
    sector = forms.ChoiceField(widget=forms.Select(attrs={'class':'form-control'}),
        label="Selecione el sector",required=False)