# -*- coding: utf-8 -*-
"""
Sistema de Consulta Pública

Copyleft (@) 2017 CENDITEL nodo Mérida - https://planificacion.cenditel.gob.ve/trac/wiki/ModeladoTopicos_2017
"""
## @package participacion.views
#
# Vistas correspondientes a la aplicación participacion
# @author Rodrigo Boet (rboet at cenditel.gob.ve)
# @author <a href='http://www.cenditel.gob.ve'>Centro Nacional de Desarrollo e Investigación en Tecnologías Libres
# (CENDITEL) nodo Mérida - Venezuela</a>
# @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
# @version 1.0
import json
from django.shortcuts import render, redirect
from django.core.urlresolvers import reverse_lazy
from django.views.generic import FormView, TemplateView
from .forms import ParticipacionSelectForm, ParticipacionSearchForm
from consulta.models import Pregunta, Opcion
import requests

class ParticipacionIndex(FormView):
    """!
    Clase que gestiona la vista principal de la participación

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 22-02-2017
    @version 1.0.0
    """
    template_name = "participacion.index.html"
    form_class = ParticipacionSelectForm
    
    def get_success_url(self):
        """!
        Metodo que permite definir la url de dirección al ser válido el formulario
    
        @author Rodrigo Boet (rboet at cenditel.gob.ve)
        @copyright GNU/GPLv2
        @date 22-02-2017
        @param self <b>{object}</b> Objeto que instancia la clase
        @return Retorna la url
        """
        consulta = self.request.POST['consultas']
        return reverse_lazy('participacion_busqueda',
                            kwargs={'pk': consulta})


class ParticipacionSearch(FormView):
    """!
    Clase que gestiona la busqueda para la participación

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 23-02-2017
    @version 1.0.0
    """
    template_name = "participacion.search.html"
    form_class = ParticipacionSearchForm
    
    def get_success_url(self):
        """!
        Metodo que permite definir la url de dirección al ser válido el formulario
    
        @author Rodrigo Boet (rboet at cenditel.gob.ve)
        @copyright GNU/GPLv2
        @date 23-02-2017
        @param self <b>{object}</b> Objeto que instancia la clase
        @return Retorna la url
        """
        entes = self.request.POST['entes']
        return reverse_lazy('participacion_entes', kwargs={'pk': self.kwargs['pk'],'id_ente':entes})


class ParticipacionCreate(TemplateView):
    """!
    Clase que gestiona la vista principal de la participación

    @author Rodrigo Boet (rboet at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 22-02-2017
    @version 1.0.0
    """
    template_name = "participacion.create.html"
    
    def get_context_data(self, **kwargs):
        """!
        Metodo que permite cargar de nuevo valores en los datos de contexto de la vista
    
        @author Rodrigo Boet (rboet at cenditel.gob.ve)
        @copyright GNU/GPLv2
        @date 23-02-2017
        @param self <b>{object}</b> Objeto que instancia la clase
        @param kwargs <b>{object}</b> Objeto que contiene los datos de contexto
        @return Retorna los datos de contexto
        """
        valores = {}
        for pregunta in Pregunta.objects.filter(consulta_id=kwargs['pk']).all():
            label = '<label>'+pregunta.texto_pregunta+'</label>'
            campo = ''
            if pregunta.tipo_pregunta.id == 1:
                campo = ''
                for opcion in Opcion.objects.filter(pregunta_id=pregunta.id).all():
                    campo += '<label for="'+kwargs['pk']+'">'+opcion.texto_opcion+'</label><input type="radio" name="consulta_respuesta_radio_'+kwargs['pk']+'" id="'+kwargs['pk']+'"value="'+str(opcion.id)+'" class="icheck">'
            elif pregunta.tipo_pregunta.id == 2:
                campo = ''
                for opcion in Opcion.objects.filter(pregunta_id=pregunta.id).all():
                    campo += '<label for="'+kwargs['pk']+'">'+opcion.texto_opcion+'</label><input type="checkbox" name="consulta_respuesta_check_'+kwargs['pk']+'" id="'+kwargs['pk']+'"value="'+str(opcion.id)+'" class="icheck">'
            elif pregunta.tipo_pregunta.id > 2 and pregunta.tipo_pregunta.id < 5:
                campo += '<label for="'+kwargs['pk']+'">Si</label><input type="radio" name="consulta_respuesta_sino_'+kwargs['pk']+'" id="'+kwargs['pk']+'"value="Si" class="icheck">'
                if(pregunta.tipo_pregunta.id == 3):
                    campo += '<label for="'+kwargs['pk']+'">No</label><input type="radio" name="consulta_respuesta_sino_'+kwargs['pk']+'" id="'+kwargs['pk']+'"value="No" class="icheck">'
                else:
                    campo += '<label for="'+kwargs['pk']+'">No</label><input type="radio" name="consulta_respuesta_sino_'+kwargs['pk']+'" id="'+kwargs['pk']+'"value="No" class="icheck need_justification">'
                    campo += '<div id="div_justificar_'+kwargs['pk']+'" style="display:none;"><label>Justifique su Respuesta</label>'
                    campo += '<textarea class="form-control" id="respuesta_justificar_'+kwargs['pk']+'" name="consulta_respuesta_justificar_'+kwargs['pk']+'">'
                    campo += '</textarea></div>'
            else:
                campo = '<textarea class="form-control" name="consulta_respuesta_abierta_'+kwargs['pk']+'"></textarea>'
            valores[pregunta.id] = {'label':label,'field':campo}
            kwargs['preguntas'] = valores
        return super(ParticipacionCreate, self).get_context_data(**kwargs)
    
    def post(self,request,pk):
        """!
        Metodo que sobreescribe el post del formulario
    
        @author Rodrigo Boet (rboet at cenditel.gob.ve)
        @copyright GNU/GPLv2
        @date 20-03-2017
        @param self <b>{object}</b> Objeto que instancia la clase
        @param request <b>{object}</b> Objeto que instancia la petición
        @param pk <b>{int}</b> Recibe el id de la consulta
        @return Retorna los datos de contexto
        """
        print request.POST
        return redirect(reverse_lazy('participacion_consulta',kwargs={'pk':pk}))


class ParticipacionEntes(TemplateView):
    """!
    Clase que gestiona la vista de los entes adscritos

    @author Argenis Osorio (aosorio at cenditel.gob.ve)
    @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
    @date 07-04-2017
    @version 1.0.0
    """
    template_name = "participacion.entes.html"

    def get_context_data(self, **kwargs):
        """!
        Metodo que permite cargar los datos de los entes adscritos

        @author Argenis Osorio (aosorio at cenditel.gob.ve)
        @copyright GNU/GPLv2
        @date 07-04-2017
        @param self <b>{object}</b> Objeto que instancia la clase
        @param kwargs <b>{object}</b> Objeto que contiene los datos de contexto
        @return Retorna los datos de contexto
        """
        url = "http://192.168.12.152:8080/services_sipes/entes_planificadores/views/servicios_webs?display_id=page_2&parent="+str(kwargs['id_ente'])

        r = requests.get(url)
        if not r.status_code == 200:
            print "ERROR:"
            return ('', 'ocurrio error...'),
        data = r.json()
        kwargs['data'] = data
        return super(ParticipacionEntes, self).get_context_data(**kwargs)